clear
close all;
fs = 300;
f1 = 5;
f2 = 15;
t= [0:1/fs:1];
f= [0:fs/length(t):fs-0.00001] ;
% Time Domain input
x1 = sin(2*pi*f1*t);
x2 = sin(2*pi*f2*t);
x=x1+x2;
% Frequency Domain input
X1=20*log10(abs(fft(x1)));
X2=20*log10(abs(fft(x2)));
X =20*log10(abs(fft(x)));

% Plot inputs
figure
subplot(2,3,1);
plot(t,x1);grid on;
title('Low Frequency');
subplot(2,3,2);
plot(t,x2);grid on;
title('High Frequency');
subplot(2,3,3);
plot(t,x);grid on;
title('Both Frequencies');
subplot(2,3,4);
plot(f,X1);grid on;
subplot(2,3,5);
plot(f,X2);grid on;
subplot(2,3,6);
plot(f,X);grid on;

% Design FIR filters
fir_order =100;
fc1=7 ;
fc2 = 12 ;
lpf_fir = fir1(fir_order,fc1/(fs/2));
LPF_FIR=20*log10(abs(fft(lpf_fir)));
hpf_fir = fir1(fir_order,fc2/(fs/2),'high');
HPF_FIR=20*log10(abs(fft(hpf_fir)));
f_fir_x_axis = [0:fs/fir_order:fs] ;

% Plot Frequency Responses of FIR filters
figure
subplot(2,2,1);
plot(f_fir_x_axis,LPF_FIR);grid on;
title('LPF FIR');
subplot(2,2,2);
plot(f_fir_x_axis,HPF_FIR);grid on;
title('HPF FIR');

% Design IIR filters
iir_order = 6;
N_IIR_FREQ_RESPONSE = 200 ; % set freqiemcu resolution for frequency response
[b_lpf,a_lpf]=butter(iir_order,fc1/(fs/2));
LPF_IIR=20*log10(abs(freqz(b_lpf,a_lpf,N_IIR_FREQ_RESPONSE,'whole')));
[b_hpf,a_hpf]=butter(iir_order,fc2/(fs/2),'high');
HPF_IIR=20*log10(abs(freqz(b_hpf,a_hpf,N_IIR_FREQ_RESPONSE,'whole')));

% Plot Frequency Responses of IIR filters
subplot(2,2,3)
f_iir_x_axis = [0:fs/N_IIR_FREQ_RESPONSE:fs-0.00001] ;
plot(f_iir_x_axis,LPF_IIR);grid on;
title('LPF IIR');
subplot(2,2,4)
plot(f_iir_x_axis,HPF_IIR);grid on;
title('HPF IIR');

% Implement Filters
y1= filter(lpf_fir,1,x);
y2=filter(hpf_fir,1,x);
y3=filter(b_lpf,a_lpf,x);
y4=filter(b_hpf,a_hpf,x);

% Plot filter outputs
figure
subplot(2,2,1)
plot(y1);grid on;
title('LPF FIR');
subplot(2,2,2)
plot(y2);grid on;
title('HPF FIR');
subplot(2,2,3)
plot(y3);grid on;
title('LPF IIR');
subplot(2,2,4)
plot(y4);grid on;
title('HPF IIR');

 